#
#
# $Id$
#
# This program is free software; you can redistribute it and/or 
# modify it under the terms of the GNU General Public License, version 2.
#
# Infobrowser support for the BBC Whats On  items
#
package Plugins::InfoBrowserAddons::RecentlyPlayedRadioParadise::RecentlyPlayedRadioParadiseParser;

# Parser for www.radioparadise.com's recently played page

use strict;

use Slim::Utils::Log;

use HTML::PullParser;
use HTML::Entities;
use Date::Parse qw(str2time);
use Data::Dumper;

my $log = logger('plugin.infobrowser');


sub getDisplayName { 'Recently Played Radio Paradise ' };

sub getnexttag
{
  my $t;
  my $p         = shift;
  my $searchtag = shift;
  my $exittag   = shift ;

  for (;;) {
     $t = $p->get_token();
     return undef unless (defined($t));
     return $t if ( $t->[1] eq $searchtag) ;
     return $t if ( defined ($exittag) && $t->[1] eq $exittag) ;
  }
}


sub cleanup
{
  my $str = shift;
  return undef unless defined ($str); 
  
  $str =~ s/\n/ /g;  # change LF to space
  $str =~ s/\r//g;   # Get rid of CR if any.
  $str =~ s/&nbsp;/ /g; # replace HTML &nbsp if any.

# strip whitespace from beginning and end

  $str =~ s/^\s*//; 
  $str =~ s/\s*$//; 
  

  return $str;
}

sub parse
{
	my $class  = shift;
	my $http   = shift;

	my $params = $http->params('params');
	my $url    = $params->{'url'};
	my $title  = $params->{'text'};
	my @list;
	my $token;
	my ( $playedtime , $playedsong);

	my $p = HTML::PullParser->new(api_version => 3, doc => ${$http->contentRef},
		      	    	  start => 'event, tag, attr,  skipped_text',
			    	  end   => 'event, tag, dtext, skipped_text',
			          report_tags => [qw ( hr a td br)]);

	$token = getnexttag($p,"hr");

	while (defined($token) && ($token->[1] ne "/td") ) {
#		possible tokens are br or hr
		if ( $token->[1] ne "a") {
			$token = getnexttag($p,"a");
		};
		$playedtime = cleanup ($token->[3] ) ;
		$token = getnexttag($p,"/a");
		last unless defined($token);

		$playedsong = cleanup ($token->[3] ) ;

	        $log->debug("date=$playedtime song=$playedsong ");
	        push @list,{'name'   =>  "$playedtime   $playedsong" };

 		$token = $p->get_token();
	}	

	return {
		'type'  => 'opml',
		'title' => "$title",
		'name' => "RecentlyPlayedRadioParadise - parsed",
		'items' => [@list],
	};

}

# Local Variables:
# tab-width:4
# indent-tabs-mode:t
# End:

1;
